##Osuri et al. 2019/20
##Greater stability of carbon capture in
##species-rich natural forests compared to species-poor plantations

library(matrixStats)
library(Hmisc)
library(vegan)
library(gmodels)
setwd('C:/work_folder/c_seq_study/data/data_upload')
Plot.table<-read.csv('ATR_locs.csv')
Plot.table$class<-ifelse(Plot.table$class=="EF",'A.EF',ifelse(Plot.table$class=="DF",'B.DF',ifelse(Plot.table$class=="TP",'C.TP','D.EP')))
env_variables<-read.csv('ATR_environment_data.csv')
prec<-read.csv('prec_2000_18.csv')
vegdat<-read.csv('ATR_plot_data.csv',header=T)
Plots<-sort(unique(vegdat$Plot_id))
Rain<-env_variables$prec[match(Plots,env_variables$name)]
Elev<-env_variables$elev[match(Plots,env_variables$name)]
Carbon<-tapply(vegdat$carbon,vegdat$Plot_id,sum)/1000
spric<-tapply(vegdat$carbon,list(vegdat$acc.name,vegdat$Plot_id),length)
spric<-ifelse(is.na(spric)==T,0,1)
Spric<-colSums(spric)

Treeden<-tapply(vegdat$carbon,vegdat$Plot_id,length)
Plot.table$Rain<-Rain[match(Plot.table$name,Plots)]
Plot.table$Elev<-Elev[match(Plot.table$name,Plots)]
Plot.table$Treeden<-Treeden[match(Plot.table$name,Plots)]
Plot.table$Spric<-Spric[match(Plot.table$name,Plots)]
Plot.table$Carbon<-Carbon[match(Plot.table$name,Plots)]

Class<-sort(unique(Plot.table$class))
Nplot<-tabulate(factor(Plot.table$class))
Elev_av<-round(tapply(Plot.table$Elev,Plot.table$class,mean,na.rm=T),0)
Elev_sd<-round(tapply(Plot.table$Elev,Plot.table$class,sd,na.rm=T)/sqrt(Nplot),0)
Rain_av<-round(tapply(Plot.table$Rain,Plot.table$class,mean,na.rm=T),0)
Rain_sd<-round(tapply(Plot.table$Rain,Plot.table$class,sd,na.rm=T)/sqrt(Nplot),0)
# Manuscript Table 1
Table1<-data.frame(Class,Nplot,Rain_av,Rain_sd,Elev_av,Elev_sd)

##EVI
Wet<-read.csv('ATR_EVI_wet.csv')
Dry<-read.csv('ATR_EVI_dry.csv')
Dry_fire<-read.csv('ATR_EVI_dry_burn.csv')
dry_mat_withfire<-as.matrix(Dry[,3:21])
Burn_mat<-as.matrix(Dry_fire[,3:21])
Burn<-which(is.na(Burn_mat)==F)
dry_mat_withoutfire<-dry_mat_withfire
dry_mat_withoutfire[Burn]<-NA

dry_mat<-dry_mat_withfire # replace with dry_mat_withoutfire for analysis excluding burnt areas
wet_mat<-as.matrix(Wet[,3:21])

dry_av<-rowMeans(dry_mat,na.rm=T)
dry_dr<-rowMeans(dry_mat[,c(3,4,14,17)],na.rm=T)
dry_diff<-log(dry_dr/dry_av)
dry_stab<-1/(rowSds(dry_mat,na.rm=T)/dry_av)

wet_av<-rowMeans(wet_mat,na.rm=T)
wet_dr<-rowMeans(wet_mat[,c(3,4,14,17)],na.rm=T)
wet_diff<-log(wet_dr/wet_av)
wet_stab<-1/(rowSds(wet_mat,na.rm=T)/wet_av)

Plot.table$Dry_av<-dry_av[match(Plot.table$name,Dry$name)]
Plot.table$Dry_diff<-dry_diff[match(Plot.table$name,Dry$name)]
Plot.table$Dry_stab<-dry_stab[match(Plot.table$name,Dry$name)]

Plot.table$Wet_av<-wet_av[match(Plot.table$name,Wet$name)]
Plot.table$Wet_diff<-wet_diff[match(Plot.table$name,Wet$name)]
Plot.table$Wet_stab<-wet_stab[match(Plot.table$name,Wet$name)]
Plot.table<-droplevels(Plot.table[complete.cases(Plot.table$xcoord),])
Names<-c('EF','DF','TP','EP')
Cols<-c('dark green','green','blue','sky blue')
Class<-Plot.table$class
Rain<-as.numeric(scale(Plot.table$Rain))

##cluster 1: 
#Species richness

Resp<-Plot.table$Spric
#throughout, m1 models do not include rainfall as predictor, while m2 models do
m1<-glm(Resp~Class,family=poisson)
newdat_Sp<-data.frame('Class'=sort(unique(Class)))
Pred<-predict.glm(m1,newdat_Sp,se.fit = T)
newdat_Sp$Fit<-round(exp(Pred$fit),2)
newdat_Sp$Lo<-newdat_Sp$Fit-round(1.96*exp(Pred$se.fit),2)
newdat_Sp$Hi<-newdat_Sp$Fit+round(1.96*exp(Pred$se.fit),2)

m2<-glm(Resp~Class+Rain,family=poisson)
newdat_SpR<-expand.grid('Class'=sort(unique(Class)),'Rain'=0)
Pred<-predict.glm(m2,newdat_SpR,se.fit = T)
newdat_SpR$Fit<-round(exp(Pred$fit),2)
newdat_SpR$Lo<-newdat_SpR$Fit-round(1.96*exp(Pred$se.fit),2)
newdat_SpR$Hi<-newdat_SpR$Fit+round(1.96*exp(Pred$se.fit),2)

#Fig 2a
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
Bar<-barplot(newdat_Sp$Fit,col=Cols,ylim=c(0,18),xaxt='n',yaxt='n')
errbar(Bar,newdat_Sp$Fit,newdat_Sp$Lo,newdat_Sp$Hi,add=T,pch=NA,lwd=2)
axis(1,c(0,Bar,5),c("NA",Names,"NA"),lwd=2)
title(ylab='Species density (Species/0.04 ha)',line=3.5)
axis(2,seq(0,18,3),seq(0,18,3),lwd=2)
text(Bar,newdat_Sp$Hi+0.05*max(newdat_Sp$Hi),c('a','b','c','c'),cex=2)


#Carbon stock
Resp<-log(Plot.table$Carbon)
m1<-lm(Resp~Class)
newdat_Ca<-data.frame('Class'=sort(unique(Class)))
Pred<-predict(m1,newdat_Ca,interval = 'confidence')
newdat_Ca$Fit<-round(exp(Pred[,1]),2)
newdat_Ca$Lo<-round(exp(Pred[,2]),2)
newdat_Ca$Hi<-round(exp(Pred[,3]),2)

m2<-lm(Resp~Class+Rain)
newdat_CaR<-expand.grid('Class'=sort(unique(Class)),'Rain'=0)
Pred<-predict(m2,newdat_CaR,interval = 'confidence')
newdat_CaR$Fit<-round(exp(Pred[,1]),2)
newdat_CaR$Lo<-round(exp(Pred[,2]),2)
newdat_CaR$Hi<-round(exp(Pred[,3]),2)

#Fig 2c
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
Bar<-barplot(log(newdat_Ca$Fit),col=Cols,ylim=c(0,log(16)),xaxt='n',yaxt='n')
errbar(Bar,log(newdat_Ca$Fit),log(newdat_Ca$Lo),log(newdat_Ca$Hi),add=T,pch=NA,lwd=2)
axis(1,c(0,Bar,5),c("NA",Names,"NA"),lwd=2)
title(ylab='Carbon density (Mg/0.04 ha)',line=3.5)
axis(2,log(c(0,1,4,16)),c(0,1,4,16),lwd=2)
text(Bar,log(newdat_Ca$Hi)+0.05*max(log(newdat_Ca$Hi)),c('a','b','b','c'),cex=2)


#rarefaction
EFdat<-droplevels(subset(vegdat,Veg_type=="Evergreen"))
EFmat<-tapply(EFdat$carbon,list(EFdat$Plot_id,EFdat$acc.name),length)
EFmat[is.na(EFmat)==T]<-0
EFaccum<-specaccum(EFmat,"exact")

DFdat<-droplevels(subset(vegdat,Veg_type=="Moist deciduous"))
DFmat<-tapply(DFdat$carbon,list(DFdat$Plot_id,DFdat$acc.name),length)
DFmat[is.na(DFmat)==T]<-0
DFaccum<-specaccum(DFmat,"exact")

TPdat<-droplevels(subset(vegdat,Veg_type=="Teak plantation"))
TPmat<-tapply(TPdat$carbon,list(TPdat$Plot_id,TPdat$acc.name),length)
TPmat[is.na(TPmat)==T]<-0
TPaccum<-specaccum(TPmat,"exact")

EPdat<-droplevels(subset(vegdat,Veg_type=="Eucalyptus plantation"))
EPmat<-tapply(EPdat$carbon,list(EPdat$Plot_id,EPdat$acc.name),length)
EPmat[is.na(EPmat)==T]<-0
EPaccum<-specaccum(EPmat,"exact")

#Fig2b
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2,font=1)
plot(EFaccum,ci=2,ci.type='bar',col='dark green',lwd=2,xlab='No. of plots',ylab=NA,ylim=c(0,300),xlim=c(0,90),bty='na',xaxt='n',yaxt='n')
axis(1,seq(0,90,30),seq(0,90,30),lwd=2)
axis(2,seq(0,300,100),seq(0,300,100),lwd=2)
title(ylab='No. of species',line=4)
plot(DFaccum,ci=2,ci.type='bar',col='green',lwd=2,add=T)
plot(TPaccum,ci=2,ci.type='bar',col='blue',lwd=2,add=T)
plot(EPaccum,ci=2,ci.type='bar',col='sky blue',lwd=2,add=T)
legend('bottomright',lty=1,lwd=4,col=c('dark green','green','blue','sky blue'),c('EF','DF','TP','EP'),bty='n',cex=1.2)


#cluster 2: EVI average and stability
#Wet season average EVI
Resp<-Plot.table$Wet_av
m1<-lm(Resp~Class)
newdat_Wa<-data.frame('Class'=sort(unique(Class)))
Pred<-predict(m1,newdat_Wa,interval = 'confidence')
newdat_Wa$Fit<-round(Pred[,1],3)
newdat_Wa$Lo<-round(Pred[,2],3)
newdat_Wa$Hi<-round(Pred[,3],3)

m2<-lm(Resp~Class+Rain)
newdat_WaR<-expand.grid('Class'=sort(unique(Class)),'Rain'=0)
Pred<-predict(m2,newdat_WaR,interval = 'confidence')
newdat_WaR$Fit<-round(Pred[,1],3)
newdat_WaR$Lo<-round(Pred[,2],3)
newdat_WaR$Hi<-round(Pred[,3],3)

#Fig3a
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
Bar<-barplot(newdat_Wa$Fit,col=Cols,ylim=c(0.2,0.5),xpd=F,xaxt='n',yaxt='n')
errbar(Bar,newdat_Wa$Fit,newdat_Wa$Lo,newdat_Wa$Hi,add=T,pch=NA,lwd=2)
axis(1,c(0,Bar,5),c("NA",Names,"NA"),lwd=2)
axis(2,c(0.2,0.3,0.4,0.5,0.6),c("0.2","0.3","0.4","0.5","0.6"),lwd=2)
title(ylab='Average EVI',line=4)
text(Bar,newdat_Wa$Hi+0.03*max(newdat_Wa$Hi),c('a','b','c','c'),cex=2)

#Dry season average EVI
Resp<-Plot.table$Dry_av
m1<-lm(Resp~Class)
newdat_Da<-data.frame('Class'=sort(unique(Class)))
Pred<-predict(m1,newdat_Da,interval = 'confidence')
newdat_Da$Fit<-round(Pred[,1],3)
newdat_Da$Lo<-round(Pred[,2],3)
newdat_Da$Hi<-round(Pred[,3],3)

m2<-lm(Resp~Class+Rain)
newdat_DaR<-expand.grid('Class'=sort(unique(Class)),'Rain'=0)
Pred<-predict(m2,newdat_DaR,interval = 'confidence')
newdat_DaR$Fit<-round(Pred[,1],3)
newdat_DaR$Lo<-round(Pred[,2],3)
newdat_DaR$Hi<-round(Pred[,3],3)

#Fig3b
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
Bar<-barplot(newdat_Da$Fit,col=Cols,ylim=c(0.2,0.5),xpd=F,xaxt='n',yaxt='n')
errbar(Bar,newdat_Da$Fit,newdat_Da$Lo,newdat_Da$Hi,add=T,pch=NA,lwd=2)
axis(1,c(0,Bar,5),c("NA",Names,"NA"),lwd=2)
axis(2,c(0.2,0.3,0.4,0.5,0.6),c("0.2","0.3","0.4","0.5","0.6"),lwd=2)
title(ylab='Average EVI',line=4)
text(Bar,newdat_Da$Hi+0.05*max(newdat_Da$Hi),c('a','b','c','d'),cex=2)

#Wet season EVI stability
Resp<-Plot.table$Wet_stab
m1<-lm(Resp~Class)
newdat_Ws<-data.frame('Class'=sort(unique(Class)))
Pred<-predict(m1,newdat_Ws,interval = 'confidence')
newdat_Ws$Fit<-round(Pred[,1],3)
newdat_Ws$Lo<-round(Pred[,2],3)
newdat_Ws$Hi<-round(Pred[,3],3)

m2<-lm(Resp~Class+Rain)
newdat_WsR<-expand.grid('Class'=sort(unique(Class)),'Rain'=0)
Pred<-predict(m2,newdat_WsR,interval = 'confidence')
newdat_WsR$Fit<-round(Pred[,1],3)
newdat_WsR$Lo<-round(Pred[,2],3)
newdat_WsR$Hi<-round(Pred[,3],3)

#Fig3c
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
Bar<-barplot(newdat_Ws$Fit,col=Cols,ylim=c(0,25),xpd=F,xaxt='n',yaxt='n')
errbar(Bar,newdat_Ws$Fit,newdat_Ws$Lo,newdat_Ws$Hi,add=T,pch=NA,lwd=2)
axis(1,c(0,Bar,5),c("NA",Names,"NA"),lwd=2)
axis(2,c(-10,0,5,10,15,20,25),lwd=2)
title(ylab='Stability of EVI',line=4)
text(Bar,newdat_Ws$Hi+0.1*max(newdat_Ws$Hi),c('a','b','c','d'),cex=2)

#Dry season EVI stability
Resp<-Plot.table$Dry_stab
m1<-lm(Resp~Class)
newdat_Ds<-data.frame('Class'=sort(unique(Class)))
Pred<-predict(m1,newdat_Ds,interval = 'confidence')
newdat_Ds$Fit<-round(Pred[,1],3)
newdat_Ds$Lo<-round(Pred[,2],3)
newdat_Ds$Hi<-round(Pred[,3],3)

m2<-lm(Resp~Class+Rain)
newdat_DsR<-expand.grid('Class'=sort(unique(Class)),'Rain'=0)
Pred<-predict(m2,newdat_DsR,interval = 'confidence')
newdat_DsR$Fit<-round(Pred[,1],3)
newdat_DsR$Lo<-round(Pred[,2],3)
newdat_DsR$Hi<-round(Pred[,3],3)

#Fig3d
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
Bar<-barplot(newdat_Ds$Fit,col=Cols,ylim=c(0,25),xpd=F,xaxt='n',yaxt='n')
errbar(Bar,newdat_Ds$Fit,newdat_Ds$Lo,newdat_Ds$Hi,add=T,pch=NA,lwd=2)
axis(1,c(0,Bar,5),c("NA",Names,"NA"),lwd=2)
axis(2,c(-10,0,5,10,15,20,25),lwd=2)
title(ylab='Stability of EVI',line=4)
text(Bar,newdat_Ds$Hi+0.1*max(newdat_Ds$Hi),c('a','b','c','d'),cex=2)

# cluster 3: Drought response
#Wet season EVI difference (log ratio of drought to non-drought year)
Resp<-Plot.table$Wet_diff
m1<-lm(Resp~Class)
newdat_Wd<-data.frame('Class'=sort(unique(Class)))
Pred<-predict(m1,newdat_Wd,interval = 'confidence')
newdat_Wd$Fit<-round(Pred[,1],3)
newdat_Wd$Lo<-round(Pred[,2],3)
newdat_Wd$Hi<-round(Pred[,3],3)

m2<-lm(Resp~Class+Rain)
newdat_WdR<-expand.grid('Class'=sort(unique(Class)),'Rain'=0)
Pred<-predict(m2,newdat_WdR,interval = 'confidence')
newdat_WdR$Fit<-round(Pred[,1],3)
newdat_WdR$Lo<-round(Pred[,2],3)
newdat_WdR$Hi<-round(Pred[,3],3)

#Fig4a
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
Bar<-barplot(newdat_Wd$Fit,col=Cols,ylim=c(-0.2,0.1),xpd=F,xaxt='n',yaxt='n')
errbar(Bar,newdat_Wd$Fit,newdat_Wd$Lo,newdat_Wd$Hi,add=T,pch=NA,lwd=2)
axis(1,c(0,Bar,5),c("NA",Names,"NA"),lwd=2)
axis(2,seq(-0.3,0.1,0.1),c("NA","-0.2","-0.1","0.0","0.1"),lwd=2)
abline(0,0,lwd=2)
title(ylab=expression("EVI"[diff]),line=4)
text(Bar,newdat_Wd$Lo+0.1*min(newdat_Wd$Lo),c('a','b','c','d'),cex=2)

#Dry season EVI difference (log ratio of drought to non-drought year)
Resp<-Plot.table$Dry_diff
m1<-lm(Resp~Class)
newdat_Dd<-data.frame('Class'=sort(unique(Class)))
Pred<-predict(m1,newdat_Dd,interval = 'confidence')
newdat_Dd$Fit<-round(Pred[,1],3)
newdat_Dd$Lo<-round(Pred[,2],3)
newdat_Dd$Hi<-round(Pred[,3],3)

m2<-lm(Resp~Class+Rain)
newdat_DdR<-expand.grid('Class'=sort(unique(Class)),'Rain'=0)
Pred<-predict(m2,newdat_DdR,interval = 'confidence')
newdat_DdR$Fit<-round(Pred[,1],3)
newdat_DdR$Lo<-round(Pred[,2],3)
newdat_DdR$Hi<-round(Pred[,3],3)

#Fig4b
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
Bar<-barplot(newdat_Dd$Fit,col=Cols,ylim=c(-0.2,0.1),xpd=F,xaxt='n',yaxt='n')
errbar(Bar,newdat_Dd$Fit,newdat_Dd$Lo,newdat_Dd$Hi,add=T,pch=NA,lwd=2)
axis(1,c(0,Bar,5),c("NA",Names,"NA"),lwd=2)
axis(2,seq(-0.3,0.1,0.1),c("NA","-0.2","-0.1","0.0","0.1"),lwd=2)
abline(0,0,lwd=2)
title(ylab=expression("EVI"[diff]),line=4)
text(Bar,newdat_Dd$Lo+0.05*min(newdat_Dd$Lo),c('a','b','c','d'),cex=2)

#Table S1
T1<-rbind(newdat_Sp,newdat_Ca,newdat_Wa,newdat_Da,newdat_Ws,newdat_Ds,newdat_Dd,newdat_Wd)
T2<-rbind(newdat_SpR,newdat_CaR,newdat_WaR,newdat_DaR,newdat_WsR,newdat_DsR,newdat_DdR,newdat_WdR)
T2<-T2[,c(1,3:5)]
Response<-c(rep("Sp",4),rep("Ca",4),rep("Wa",4),rep("Da",4),rep("Ws",4),rep("Ds",4),rep("Dd",4),rep("Wd",4))
TableS1<-data.frame(Response,T1,T2)


#Drought difference (SI)

EF<-colMeans(dry_mat[Dry$class=="EF",],na.rm=T)
DF<-colMeans(dry_mat[Dry$class=="DF",],na.rm=T)
TP<-colMeans(dry_mat[Dry$class=="TP",],na.rm=T)
EP<-colMeans(dry_mat[Dry$class=="EP",],na.rm=T)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
plot(EF,type='l',col='dark green',lwd=3,ylim=c(0.15,0.50),ylab=NA,xlab='Year',xaxt='n',yaxt='n',bty='n')
points(EF,pch=19,cex=0.8,col='dark green')
axis(1,c(0,seq(1,19,6)),c(1999,seq(2000,2018,6)),lwd=2)
axis(2,seq(0.1,0.5,0.1),lwd=2)
title(ylab="EVI",line=4.5)
points(DF,type='l',col='green',lwd=3)
points(DF,pch=19,col='green')
points(TP,type='l',col='blue',lwd=3)
points(TP,pch=19,col='blue')
points(EP,type='l',col='sky blue',lwd=3)
points(EP,pch=19,col='sky blue')
lines(rep(3,2),c(0,1),lty=2)
lines(rep(4,2),c(0,1),lty=2)
lines(rep(14,2),c(0,1),lty=2)
lines(rep(17,2),c(0,1),lty=2)

EF_sim_nd<-EF[c(1,2,5:10,12,13,15,16,18,19)]
EF_sim_d<-EF[c(3,4,14,17)]
DF_sim_nd<-DF[c(1,2,5:10,12,13,15,16,18,19)]
DF_sim_d<-DF[c(3,4,14,17)]
TP_sim_nd<-TP[c(1,2,5:10,12,13,15,16,18,19)]
TP_sim_d<-TP[c(3,4,14,17)]
EP_sim_nd<-EP[c(1,2,5:10,12,13,15,16,18,19)]
EP_sim_d<-EP[c(3,4,14,17)]

##simulation

D_EF<-matrix(0,nrow=100,ncol=3)
D_DF<-matrix(0,nrow=100,ncol=3)
D_TP<-matrix(0,nrow=100,ncol=3)
D_EP<-matrix(0,nrow=100,ncol=3)
for (i in 1:100){
  D_EF[i,1]<-sum(sample(EF_sim_nd,10,replace=T))
  D_EF[i,2]<-sum(c(sample(EF_sim_nd,8,replace=T),sample(EF_sim_d,2,replace=T)))
  D_EF[i,3]<-sum(c(sample(EF_sim_nd,6,replace=T),sample(EF_sim_d,4,replace=T)))
  
  D_DF[i,1]<-sum(sample(DF_sim_nd,10,replace=T))
  D_DF[i,2]<-sum(c(sample(DF_sim_nd,8,replace=T),sample(DF_sim_d,2,replace=T)))
  D_DF[i,3]<-sum(c(sample(DF_sim_nd,6,replace=T),sample(DF_sim_d,4,replace=T)))
  
  D_TP[i,1]<-sum(sample(TP_sim_nd,10,replace=T))
  D_TP[i,2]<-sum(c(sample(TP_sim_nd,8,replace=T),sample(TP_sim_d,2,replace=T)))
  D_TP[i,3]<-sum(c(sample(TP_sim_nd,6,replace=T),sample(TP_sim_d,4,replace=T)))
  
  D_EP[i,1]<-sum(sample(EP_sim_nd,10,replace=T))
  D_EP[i,2]<-sum(c(sample(EP_sim_nd,8,replace=T),sample(EP_sim_d,2,replace=T)))
  D_EP[i,3]<-sum(c(sample(EP_sim_nd,6,replace=T),sample(EP_sim_d,4,replace=T)))
  
}
#Fig 6a
Response<-100*(colMeans(D_TP)-colMeans(D_DF))/colMeans(D_TP)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
bar<-barplot(Response,col='dark orange',xpd=F,xaxt='n',yaxt='n',ylim=c(-30,0),xlab='No. drought years')
axis(1,0:4,c(NA,0,2,4,NA),lwd=2)
title(ylab='% difference (TP-DF)',line=3.5)
axis(2,seq(-40,0,10),lwd=2)
abline(0,0,lwd=2)
#Fig 6b
Response<-100*(colMeans(D_TP)-colMeans(D_EF))/colMeans(D_TP)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
bar<-barplot(Response,col='dark orange',xpd=F,xaxt='n',yaxt='n',ylim=c(-50,0),xlab='No. drought years')
axis(1,0:4,c(NA,0,2,4,NA),lwd=2)
title(ylab='% difference (TP-EF)',line=3.5)
axis(2,seq(-60,0,10),lwd=2)
abline(0,0,lwd=2)

#Fig 6c
Response<-100*(colMeans(D_EP)-colMeans(D_DF))/colMeans(D_TP)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
bar<-barplot(Response,col='dark orange',xpd=F,xaxt='n',yaxt='n',ylim=c(-10,0),xlab='No. drought years')
axis(1,0:4,c(NA,0,2,4,NA),lwd=2)
title(ylab='% difference (EP-DF)',line=3.5)
axis(2,seq(-20,0,2),lwd=2)
abline(0,0,lwd=2)

#Fig 6d
Response<-100*(colMeans(D_EP)-colMeans(D_EF))/colMeans(D_TP)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
bar<-barplot(Response,col='dark orange',xpd=F,xaxt='n',yaxt='n',ylim=c(-30,0),xlab='No. drought years')
axis(1,0:4,c(NA,0,2,4,NA),lwd=2)
title(ylab='% difference (EP-EF)',line=3.5)
axis(2,seq(-40,0,10),lwd=2)
abline(0,0,lwd=2)


EF<-colMeans(wet_mat[Wet$class=="EF",],na.rm=T)
DF<-colMeans(wet_mat[Wet$class=="DF",],na.rm=T)
TP<-colMeans(wet_mat[Wet$class=="TP",],na.rm=T)
EP<-colMeans(wet_mat[Wet$class=="EP",],na.rm=T)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
plot(EF,type='l',col='dark green',lwd=3,ylim=c(0.15,0.50),ylab=NA,xlab='Year',xaxt='n',yaxt='n',bty='n')
points(EF,pch=19,cex=0.8,col='dark green')
axis(1,c(0,seq(1,19,6)),c(1999,seq(2000,2018,6)),lwd=2)
axis(2,seq(0.1,0.5,0.1),lwd=2)
title(ylab="EVI",line=4.5)
points(DF,type='l',col='green',lwd=3)
points(DF,pch=19,col='green')
points(TP,type='l',col='blue',lwd=3)
points(TP,pch=19,col='blue')
points(EP,type='l',col='sky blue',lwd=3)
points(EP,pch=19,col='sky blue')
lines(rep(3,2),c(0,1),lty=2)
lines(rep(4,2),c(0,1),lty=2)
lines(rep(14,2),c(0,1),lty=2)
lines(rep(17,2),c(0,1),lty=2)


EF_sim_nd<-EF[c(1,2,5,7,8,12,13,15,16,18)]
EF_sim_d<-EF[c(4,14,17)]
DF_sim_nd<-DF[c(1,2,5,7,8,12,13,15,16,18)]
DF_sim_d<-DF[c(4,14,17)]
TP_sim_nd<-TP[c(1,2,5,7,8,12,13,15,16,18)]
TP_sim_d<-TP[c(4,14,17)]
EP_sim_nd<-EP[c(1,2,5,7,8,12,13,15,16,18)]
EP_sim_d<-EP[c(4,14,17)]

##simulation

D_EF<-matrix(0,nrow=100,ncol=3)
D_DF<-matrix(0,nrow=100,ncol=3)
D_TP<-matrix(0,nrow=100,ncol=3)
D_EP<-matrix(0,nrow=100,ncol=3)
for (i in 1:100){
  D_EF[i,1]<-sum(sample(EF_sim_nd,10,replace=T))
  D_EF[i,2]<-sum(c(sample(EF_sim_nd,8,replace=T),sample(EF_sim_d,2,replace=T)))
  D_EF[i,3]<-sum(c(sample(EF_sim_nd,6,replace=T),sample(EF_sim_d,4,replace=T)))
  
  D_DF[i,1]<-sum(sample(DF_sim_nd,10,replace=T))
  D_DF[i,2]<-sum(c(sample(DF_sim_nd,8,replace=T),sample(DF_sim_d,2,replace=T)))
  D_DF[i,3]<-sum(c(sample(DF_sim_nd,6,replace=T),sample(DF_sim_d,4,replace=T)))
  
  D_TP[i,1]<-sum(sample(TP_sim_nd,10,replace=T))
  D_TP[i,2]<-sum(c(sample(TP_sim_nd,8,replace=T),sample(TP_sim_d,2,replace=T)))
  D_TP[i,3]<-sum(c(sample(TP_sim_nd,6,replace=T),sample(TP_sim_d,4,replace=T)))
  
  D_EP[i,1]<-sum(sample(EP_sim_nd,10,replace=T))
  D_EP[i,2]<-sum(c(sample(EP_sim_nd,8,replace=T),sample(EP_sim_d,2,replace=T)))
  D_EP[i,3]<-sum(c(sample(EP_sim_nd,6,replace=T),sample(EP_sim_d,4,replace=T)))
  
}
#Fig S5a
Response<-100*(colMeans(D_TP)-colMeans(D_DF))/colMeans(D_TP)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
bar<-barplot(Response,col='dark orange',xpd=F,xaxt='n',yaxt='n',ylim=c(0,10),xlab='No. drought years')
axis(1,0:4,c(NA,0,2,4,NA),lwd=2)
title(ylab='% difference (TP-DF)',line=3.5)
axis(2,seq(-5,15,5),lwd=2)
abline(0,0,lwd=2)
#Fig S5b
Response<-100*(colMeans(D_TP)-colMeans(D_EF))/colMeans(D_TP)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
bar<-barplot(Response,col='dark orange',xpd=F,xaxt='n',yaxt='n',ylim=c(0,15),xlab='No. drought years')
axis(1,0:4,c(NA,0,2,4,NA),lwd=2)
title(ylab='% difference (TP-EF)',line=3.5)
axis(2,seq(-5,15,5),lwd=2)
abline(0,0,lwd=2)
#Fig S5c
Response<-100*(colMeans(D_EP)-colMeans(D_DF))/colMeans(D_TP)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
bar<-barplot(Response,col='dark orange',xpd=F,xaxt='n',yaxt='n',ylim=c(0,10),xlab='No. drought years')
axis(1,0:4,c(NA,0,2,4,NA),lwd=2)
title(ylab='% difference (EP-DF)',line=3.5)
axis(2,seq(-5,15,5),lwd=2)
abline(0,0,lwd=2)
#Fig S5d
Response<-100*(colMeans(D_EP)-colMeans(D_EF))/colMeans(D_TP)
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
bar<-barplot(Response,col='dark orange',xpd=F,xaxt='n',yaxt='n',ylim=c(0,15),xlab='No. drought years')
axis(1,0:4,c(NA,0,2,4,NA),lwd=2)
title(ylab='% difference (EP-EF)',line=3.5)
axis(2,seq(-5,15,5),lwd=2)
abline(0,0,lwd=2)

#multi-site analysis
Wet<-read.csv('WetEVI_2000_18_paired.csv')
Dry<-read.csv('DryEVI_2000_18_paired.csv')
Frame<-Dry[,1:7]
dry_mat<-as.matrix(Dry[,8:ncol(Dry)])
wet_mat<-as.matrix(Wet[,8:ncol(Wet)])
Frame$dry_av<-rowMeans(dry_mat,na.rm=T)
Frame$wet_av<-rowMeans(wet_mat,na.rm=T)
Frame$dry_sd<-rowSds(dry_mat,na.rm=T)
Frame$wet_sd<-rowSds(wet_mat,na.rm=T)
Frame$dry_st<-1/(Frame$dry_sd/Frame$dry_av)
Frame$wet_st<-1/(Frame$wet_sd/Frame$wet_av)

For_dat<-droplevels(subset(Frame,class=="EF"|class=="DF"))
Pla_dat<-droplevels(subset(Frame,class=="TP"|class=="EP"))
ID<-sort(unique(Frame$ID))
Site<-Frame$Site[match(ID,Frame$ID)]
For_type<-For_dat$class[match(ID,For_dat$ID)]
Pla_type<-Pla_dat$class[match(ID,Pla_dat$ID)]
For_dry_av<-For_dat$dry_av[match(ID,For_dat$ID)]
Pla_dry_av<-Pla_dat$dry_av[match(ID,Pla_dat$ID)]
For_wet_av<-For_dat$wet_av[match(ID,For_dat$ID)]
Pla_wet_av<-Pla_dat$wet_av[match(ID,Pla_dat$ID)]
For_dry_st<-For_dat$dry_st[match(ID,For_dat$ID)]
Pla_dry_st<-Pla_dat$dry_st[match(ID,Pla_dat$ID)]
For_wet_st<-For_dat$wet_st[match(ID,For_dat$ID)]
Pla_wet_st<-Pla_dat$wet_st[match(ID,Pla_dat$ID)]


frame<-data.frame(ID,Site,For_type,Pla_type,For_dry_av,Pla_dry_av,For_wet_av,Pla_wet_av,For_dry_st,Pla_dry_st,For_wet_st,Pla_wet_st)
frame$LRR_dry_av<-log(frame$Pla_dry_av/frame$For_dry_av)
frame$LRR_wet_av<-log(frame$Pla_wet_av/frame$For_wet_av)
frame$LRR_dry_st<-log(frame$Pla_dry_st/frame$For_dry_st)
frame$LRR_wet_st<-log(frame$Pla_wet_st/frame$For_wet_st)
frame$Class<-paste(frame$For_type,frame$Pla_type,sep="_")

MW1<-ci(frame$LRR_wet_av,na.rm=T)
MW2<-ci(frame$LRR_wet_av[frame$Class=="EF_TP"],na.rm=T)
MW3<-ci(frame$LRR_wet_av[frame$Class=="DF_TP"],na.rm=T)
MW4<-ci(frame$LRR_wet_av[frame$Class=="DF_EP"],na.rm=T)

MD1<-ci(frame$LRR_dry_av,na.rm=T)
MD2<-ci(frame$LRR_dry_av[frame$Class=="EF_TP"],na.rm=T)
MD3<-ci(frame$LRR_dry_av[frame$Class=="DF_TP"],na.rm=T)
MD4<-ci(frame$LRR_dry_av[frame$Class=="DF_EP"],na.rm=T)

SW1<-ci(frame$LRR_wet_st,na.rm=T)
SW2<-ci(frame$LRR_wet_st[frame$Class=="EF_TP"],na.rm=T)
SW3<-ci(frame$LRR_wet_st[frame$Class=="DF_TP"],na.rm=T)
SW4<-ci(frame$LRR_wet_st[frame$Class=="DF_EP"],na.rm=T)

SD1<-ci(frame$LRR_dry_st,na.rm=T)
SD2<-ci(frame$LRR_dry_st[frame$Class=="EF_TP"],na.rm=T)
SD3<-ci(frame$LRR_dry_st[frame$Class=="DF_TP"],na.rm=T)
SD4<-ci(frame$LRR_dry_st[frame$Class=="DF_EP"],na.rm=T)

Av_Means<-c(MW1[1],MW2[1],MW3[1],MW4[1],NA,MD1[1],MD2[1],MD3[1],MD4[1])
Av_Lows<-c(MW1[2],MW2[2],MW3[2],MW4[2],NA,MD1[2],MD2[2],MD3[2],MD4[2])
Av_Highs<-c(MW1[3],MW2[3],MW3[3],MW4[3],NA,MD1[3],MD2[3],MD3[3],MD4[3])

#Fig 5a
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
plot(Av_Means,rev(1:length(Av_Means)),pch=19,xlim=c(-1,1),col=c(rep('purple',4),NA,rep('dark orange',4)),cex=2,xaxt='n',yaxt='n',ylab=NA,bty='n',xlab=expression('LRR'[av]))
arrows(x0=Av_Highs,y0=rev(1:length(Av_Means)),x1=Av_Lows,y1=rev(1:length(Av_Means)),angle=0,col=c(rep('purple',4),NA,rep('dark orange',4)),lwd=2)
lines(rep(0,2),c(-100,100),lty=2,lwd=2)
axis(1,c(-1,0,1),lwd=2)
axis(2,9:1,c("All","EF-TP","DF-TP","DF-EP"," ","All","EF-TP","DF-TP","DF-EP"),lwd=2)
text(rep(-1,4),9:6,c('(48)',' (8)','(32)',' (8)'),cex=1.8,pos=4)

St_Means<-c(SW1[1],SW2[1],SW3[1],SW4[1],NA,SD1[1],SD2[1],SD3[1],SD4[1])
St_Lows<-c(SW1[2],SW2[2],SW3[2],SW4[2],NA,SD1[2],SD2[2],SD3[2],SD4[2])
St_Highs<-c(SW1[3],SW2[3],SW3[3],SW4[3],NA,SD1[3],SD2[3],SD3[3],SD4[3])

#Fig 5b
par(las=1,mai=c(1,1.5,1,1),cex.lab=2,cex.axis=2,cex.main=2)
plot(St_Means,rev(1:length(St_Means)),pch=19,xlim=c(-1,1),col=c(rep('purple',4),NA,rep('dark orange',4)),cex=2,xaxt='n',yaxt='n',ylab=NA,bty='n',xlab=expression('LRR'[st]))
arrows(x0=St_Highs,y0=rev(1:length(St_Means)),x1=St_Lows,y1=rev(1:length(St_Means)),angle=0,col=c(rep('purple',4),NA,rep('dark orange',4)),lwd=2)
lines(rep(0,2),c(-100,100),lty=2,lwd=2)
axis(1,c(-1,0,1),lwd=2)
axis(2,9:1,c("All","EF-TP","DF-TP","DF-EP"," ","All","EF-TP","DF-TP","DF-EP"),lwd=2)

## correlations with age (Table 2)
TK<-droplevels(subset(Plot.table,class=="C.TP"))
X<-2019-TK$plant_y
cor.test(X,TK$Carbon)
cor.test(X,TK$Dry_av)
cor.test(X,TK$Wet_av)
cor.test(X,TK$Dry_st)
cor.test(X,TK$Wet_st)
cor.test(X,TK$Dry_diff)
cor.test(X,TK$Wet_diff)
